Cordova offer a powerful security model to provide developers with the tools to prevent unauthorised access and Cross-Site Scripting vulnerabilities

Cordova whitelist manages network security access and must authorise explicitly accessible ressources only.